@@ -13,6 +13,7 @@ from everviz.plugins.crossplot.callback.crossplot_callback import (
     get_graph_line,
 )
 from everviz.data.load_csv.get_data import get_data
+from everviz.util import base64encode
 
 
 class Crossplot(EvervizPluginABC):
@@ -102,8 +103,10 @@ class Crossplot(EvervizPluginABC):
                                 dcc.Graph(
                                     id=self.graph_id,
                                     config={
-                                        "modeBarButtonsToRemove": ["toImage"],
                                         "displaylogo": False,
+                                        "toImageButtonOptions": {
+                                            "filename": "crossplot"
+                                        },
                                     },
                                 )
                             ],
@@ -118,15 +121,12 @@ class Crossplot(EvervizPluginABC):
         @app.callback(self.plugin_data_output, [self.plugin_data_requested])
         def user_download_data(data_requested):
             if data_requested:
-                return EvervizPluginABC.plugin_data_compress(
-                    [
-                        {
-                            "filename": Path(self.data_path).name,
-                            "content": get_data(self.data_path).to_csv(),
-                        }
-                    ]
-                )
-            return ""
+                return {
+                    "filename": Path(self.data_path).name,
+                    "content": base64encode(get_data(self.data_path).to_csv()),
+                    "mime_type": "text/csv",
+                }
+            return None
 
         @app.callback(
             Output(self.graph_id, "figure"),
