@@ -9,6 +9,7 @@ import plotly.graph_objs as go
 from dash.dependencies import Output, Input
 from everviz.plugins.plugin_abc import EvervizPluginABC
 from everviz.data.load_csv.get_data import get_data
+from everviz.util import base64encode
 
 
 class DeltaPlot(EvervizPluginABC):
@@ -82,6 +83,13 @@ class DeltaPlot(EvervizPluginABC):
                 ]
             )
 
+        if "objective" in self.csv_file:
+            plot_filename = "delta_objectives"
+        elif "summary" in self.csv_file:
+            plot_filename = "delta_summary"
+        else:
+            plot_filename = "delta"
+
         return html.Div(
             [
                 html.Div(
@@ -95,7 +103,17 @@ class DeltaPlot(EvervizPluginABC):
                             },
                         ),
                         html.Div(
-                            [dcc.Graph(id=self.graph_id)],
+                            [
+                                dcc.Graph(
+                                    id=self.graph_id,
+                                    config={
+                                        "displaylogo": False,
+                                        "toImageButtonOptions": {
+                                            "filename": plot_filename
+                                        },
+                                    },
+                                )
+                            ],
                             style={"width": "69%", "display": "inline-block"},
                         ),
                     ]
@@ -107,15 +125,12 @@ class DeltaPlot(EvervizPluginABC):
         @app.callback(self.plugin_data_output, [self.plugin_data_requested])
         def user_download_data(data_requested):
             if data_requested:
-                return EvervizPluginABC.plugin_data_compress(
-                    [
-                        {
-                            "filename": Path(self.csv_file).name,
-                            "content": get_data(self.csv_file).to_csv(),
-                        }
-                    ]
-                )
-            return ""
+                return {
+                    "filename": Path(self.csv_file).name,
+                    "content": base64encode(csv=get_data(self.csv_file).to_csv()),
+                    "mime_type": "text/csv",
+                }
+            return None
 
         inputs = [Input(self.key_dropdown_id, "value")]
         data = get_data(self.csv_file)
