@@ -11,6 +11,7 @@ from plotly.colors import DEFAULT_PLOTLY_COLORS
 from dash.dependencies import Output, Input
 from everviz.data.load_csv.get_data import get_data
 from everviz.plugins.plugin_abc import EvervizPluginABC
+from everviz.util import base64encode
 
 
 class SingleObjectivesPlot(EvervizPluginABC):
@@ -64,8 +65,10 @@ class SingleObjectivesPlot(EvervizPluginABC):
                         dcc.Graph(
                             id=self.graph_id,
                             config={
-                                "modeBarButtonsToRemove": ["toImage"],
                                 "displaylogo": False,
+                                "toImageButtonOptions": {
+                                    "filename": "single_objectives"
+                                },
                             },
                         )
                     ],
@@ -79,15 +82,12 @@ class SingleObjectivesPlot(EvervizPluginABC):
         @app.callback(self.plugin_data_output, [self.plugin_data_requested])
         def user_download_data(data_requested):
             if data_requested:
-                return EvervizPluginABC.plugin_data_compress(
-                    [
-                        {
-                            "filename": Path(self.csv_file).name,
-                            "content": get_data(self.csv_file).to_csv(),
-                        }
-                    ]
-                )
-            return ""
+                return {
+                    "filename": Path(self.csv_file).name,
+                    "content": base64encode(csv=get_data(self.csv_file).to_csv()),
+                    "mime_type": "text/csv",
+                }
+            return None
 
         @app.callback(
             Output(self.graph_id, "figure"),
